@@ -182,6 +182,7 @@ def create_partitioned_indexes(
     output_root_dir: str,
     embedding_column_name: str = "embedding",
     index_key: Optional[str] = None,
+    index_path: Optional[str] = None,
     id_columns: Optional[List[str]] = None,
     should_be_memory_mappable: bool = False,
     max_index_query_time_ms: float = 10.0,
@@ -214,6 +215,7 @@ def create_partitioned_indexes(
         min_nearest_neighbors_to_retrieve=min_nearest_neighbors_to_retrieve,
         embedding_column_name=embedding_column_name,
         index_key=index_key,
+        index_path=index_path,
         max_index_memory_usage=max_index_memory_usage,
         current_memory_available=current_memory_available,
         use_gpu=use_gpu,
