@@ -306,6 +306,7 @@ def build_partitioned_indexes(
     output_root_dir: str,
     embedding_column_name: str = "embedding",
     index_key: Optional[str] = None,
+    index_path: Optional[str] = None,
     id_columns: Optional[List[str]] = None,
     max_index_query_time_ms: float = 10.0,
     max_index_memory_usage: str = "16G",
@@ -339,6 +340,9 @@ def build_partitioned_indexes(
     index_key: Optional(str)
         Optional string to give to the index factory in order to create the index.
         If None, an index is chosen based on an heuristic.
+    index_path: Optional(str)
+        Optional path to an index that will be used to add embeddings.
+        This index must be pre-trained if it needs a training
     id_columns: Optional(List[str])
         Parquet dataset column name(s) that are used as IDs for embeddings.
         A mapping from these IDs to faiss indices will be written in separate files.
@@ -392,6 +396,11 @@ def build_partitioned_indexes(
         raise ValueError(f"nb_indices_to_keep must be > 0; Got {nb_splits_per_big_index}")
     if big_index_threshold < 1:
         raise ValueError(f"big_index_threshold must be > 0; Got {big_index_threshold}")
+    if index_path is not None and not index_key:
+        raise ValueError(
+            "Please provide the index key of the input index; "
+            f"Got index_key: {index_key} and index_path: {index_path}"
+        )
     if index_key:
         n_dimensions = EmbeddingReader(
             partitions[0], file_format="parquet", embedding_column=embedding_column_name
@@ -405,6 +414,7 @@ def build_partitioned_indexes(
         output_root_dir=output_root_dir,
         embedding_column_name=embedding_column_name,
         index_key=index_key,
+        index_path=index_path,
         id_columns=id_columns,
         should_be_memory_mappable=should_be_memory_mappable,
         max_index_query_time_ms=max_index_query_time_ms,
